Crate progressed

Crate progressed 

Progressed

An easy to use and highly configurable library to show the progress of applications, calculations, etc.

Example Usage

use std::{thread, time::Duration};
use progressed::{ProgressBar, ProgressBarStyle};

for _ in ProgressBar::new(0..100)
    .set_style(ProgressBarStyle::default())
    .set_title("progress bar: ")
{
       thread::sleep(Duration::from_millis(50));
}

Structs

LoadingSpinner
Draws a loading spinner that updates when you call tick.
LoadingSpinnerStyle
Used to style a loading spinner.
ProgressBar
Draws a progress bar while iterating over a finite range.
ProgressBarStyle
Used to style a progress bar.
UnboundProgressBar
Draws a progress bar while iterating over a range.
UnboundProgressBarStyle
Used to style a progress bar.

Enums

ProgressBarLayout